"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _reactNative = require("react-native");

const useSmsRetriver = () => {
  const {
    AndroidSmsVerification
  } = _reactNative.NativeModules;
  const [message, setMessage] = (0, _react.useState)('');
  const [timeout, setTimeoutState] = (0, _react.useState)(false);
  const listenerRef = (0, _react.useRef)();
  const eventEmitter = (0, _react.useMemo)(() => new _reactNative.NativeEventEmitter(AndroidSmsVerification), [AndroidSmsVerification]);
  (0, _react.useEffect)(() => {
    const onStartListener = eventEmitter.addListener('onListenerStarted', event => console.info(event));
    const onRegisterListener = eventEmitter.addListener('onReceiverRegistered', event => console.info(event));
    const onUnregisterListener = eventEmitter.addListener('onReceiverUnregistered', event => console.info(event));
    const onReceiverTimeout = eventEmitter.addListener('onReceiverTimeout', () => setTimeoutState(true));
    return () => {
      onStartListener === null || onStartListener === void 0 ? void 0 : onStartListener.remove();
      onRegisterListener === null || onRegisterListener === void 0 ? void 0 : onRegisterListener.remove();
      onUnregisterListener === null || onUnregisterListener === void 0 ? void 0 : onUnregisterListener.remove();
      onReceiverTimeout === null || onReceiverTimeout === void 0 ? void 0 : onReceiverTimeout.remove();
    };
  }, [eventEmitter]);
  const startListener = (0, _react.useCallback)(() => {
    try {
      AndroidSmsVerification.registerBroadcastReceiver();
      AndroidSmsVerification.startBroadcastReceiver();
      setTimeoutState(false);
      listenerRef.current = eventEmitter.addListener('onMessageReceived', setMessage);
    } catch (error) {
      console.error(error);
    }
  }, [AndroidSmsVerification, eventEmitter]);
  const stopListener = (0, _react.useCallback)(() => {
    if (_reactNative.Platform.OS === 'android') {
      try {
        var _listenerRef$current;

        AndroidSmsVerification.unRegisterBroadcastReceiver();
        (_listenerRef$current = listenerRef.current) === null || _listenerRef$current === void 0 ? void 0 : _listenerRef$current.remove();
      } catch (error) {
        console.error(error);
      }
    }
  }, [AndroidSmsVerification]);
  return {
    message,
    timeout,
    startListener,
    stopListener
  };
};

var _default = _reactNative.Platform.OS === 'android' ? useSmsRetriver : () => ({
  message: '',
  timeout: false,
  startListener: () => {},
  stopListener: () => {}
});

exports.default = _default;
//# sourceMappingURL=sms-retriver.js.map